# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0btypes.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x06\n\x04Ping\"\x07\n\x05Hello\"\t\n\x07Goodbye\"\xc3\x01\n\x0cStatusUpdate\x12\'\n\x05state\x18\x01 \x01(\x0e\x32\x18.StatusUpdate.AgentState\x12\x0f\n\x07message\x18\x02 \x01(\t\"y\n\nAgentState\x12\x0b\n\x07Unknown\x10\x00\x12\x06\n\x02OK\x10\x01\x12\r\n\tRequested\x10\x02\x12\x13\n\x0f\x41waitingPromise\x10\x03\x12\x0b\n\x07Working\x10\x04\x12\x0b\n\x07Missing\x10\x05\x12\t\n\x05\x45rror\x10\x06\x12\r\n\tCompleted\x10\x07\"\xab\x01\n\x07Promise\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12$\n\x05state\x18\x04 \x01(\x0e\x32\x15.Promise.PromiseState\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\"@\n\x0cPromiseState\x12\x0b\n\x07Pending\x10\x00\x12\r\n\tFulfilled\x10\x01\x12\t\n\x05\x46inal\x10\x02\x12\t\n\x05\x45mpty\x10\x03\"\x80\x01\n\x06Result\x12 \n\x04type\x18\x01 \x01(\x0e\x32\x12.Result.ResultType\x12\x19\n\x07promise\x18\x02 \x01(\x0b\x32\x08.Promise\"9\n\nResultType\x12\n\n\x06Result\x10\x00\x12\x11\n\rPartialResult\x10\x01\x12\x0c\n\x08NoResult\x10\x02\"~\n\x03Log\x12\x1f\n\x08severity\x18\x01 \x01(\x0e\x32\r.Log.Severity\x12\x0f\n\x07message\x18\x02 \x01(\t\"E\n\x08Severity\x12\t\n\x05\x44\x65\x62ug\x10\x00\x12\x08\n\x04Info\x10\x01\x12\x0b\n\x07Warning\x10\x02\x12\t\n\x05\x45rror\x10\x03\x12\x0c\n\x08\x43ritical\x10\x04\"\x06\n\x04Halt\"\x12\n\x10HaltAndCatchFire\"\xbb\x03\n\x07Message\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05index\x18\x02 \x01(\x05\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x10\n\x08priority\x18\x04 \x01(\x05\x12,\n\x08timeSent\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08timeRecv\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\x04ping\x18\x07 \x01(\x0b\x32\x05.PingH\x00\x12\x17\n\x05hello\x18\x08 \x01(\x0b\x32\x06.HelloH\x00\x12\x1b\n\x07goodbye\x18\t \x01(\x0b\x32\x08.GoodbyeH\x00\x12%\n\x0cstatusUpdate\x18\n \x01(\x0b\x32\r.StatusUpdateH\x00\x12\x19\n\x06result\x18\x0b \x01(\x0b\x32\x07.ResultH\x00\x12\x13\n\x03log\x18\x0c \x01(\x0b\x32\x04.LogH\x00\x12\x15\n\x04halt\x18\r \x01(\x0b\x32\x05.HaltH\x00\x12-\n\x10haltAndCatchFire\x18\x0e \x01(\x0b\x32\x11.HaltAndCatchFireH\x00\x12!\n\x0b\x63reateAgent\x18\x0f \x01(\x0b\x32\n.AgentSpecH\x00\x42\n\n\x08\x63ontents\"\xc0\x02\n\tAgentSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06runner\x18\x02 \x01(\t\x12\x1f\n\nrunnerType\x18\x03 \x01(\x0e\x32\x0b.RunnerType\x12\x17\n\x0fpollInterval_ms\x18\x04 \x01(\x05\x12\x17\n\x0fpingInterval_ms\x18\x05 \x01(\x05\x12\x1a\n\x12\x61llowedPollRetries\x18\x06 \x01(\x05\x12\x1a\n\x12\x61llowedPingRetries\x18\x07 \x01(\x05\x12\x12\n\nentrypoint\x18\x08 \x01(\t\x12\x13\n\x0b\x62lackboards\x18\t \x03(\t\x12.\n\nattributes\x18\n \x03(\x0b\x32\x1a.AgentSpec.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\",\n\x0b\x43reateAgent\x12\x1d\n\tagentSpec\x18\x01 \x01(\x0b\x32\n.AgentSpec\"=\n\x12GetMessagesRequest\x12\x12\n\nstartingAt\x18\x01 \x01(\x05\x12\x13\n\x0b\x66ilterPings\x18\x02 \x01(\x08\"*\n\x0cMessageStack\x12\x1a\n\x08messages\x18\x01 \x03(\x0b\x32\x08.Message\"E\n\x03\x41\x63k\x12\x1b\n\x06status\x18\x01 \x01(\x0e\x32\x0b.Ack.Status\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x10\n\x06Status\x12\x06\n\x02OK\x10\x00*;\n\nRunnerType\x12\x0e\n\nRunnerBase\x10\x00\x12\x0c\n\x08RunnerGo\x10\x01\x12\x0f\n\x0bRunnerLocal\x10\x02\x32\x98\x01\n\x11\x42lackboardHandler\x12\x33\n\x0bGetMessages\x12\x13.GetMessagesRequest\x1a\r.MessageStack\"\x00\x12\x1f\n\x0bSendMessage\x12\x08.Message\x1a\x04.Ack\"\x00\x12-\n\x11OpenMessageStream\x12\x08.Message\x1a\x08.Message\"\x00(\x01\x30\x01\x42+Z)gitlab.com/sm-ai-team/sm-core-go/pkg/coreb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)gitlab.com/sm-ai-team/sm-core-go/pkg/core'
  _AGENTSPEC_ATTRIBUTESENTRY._options = None
  _AGENTSPEC_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _RUNNERTYPE._serialized_start=1728
  _RUNNERTYPE._serialized_end=1787
  _PING._serialized_start=48
  _PING._serialized_end=54
  _HELLO._serialized_start=56
  _HELLO._serialized_end=63
  _GOODBYE._serialized_start=65
  _GOODBYE._serialized_end=74
  _STATUSUPDATE._serialized_start=77
  _STATUSUPDATE._serialized_end=272
  _STATUSUPDATE_AGENTSTATE._serialized_start=151
  _STATUSUPDATE_AGENTSTATE._serialized_end=272
  _PROMISE._serialized_start=275
  _PROMISE._serialized_end=446
  _PROMISE_PROMISESTATE._serialized_start=382
  _PROMISE_PROMISESTATE._serialized_end=446
  _RESULT._serialized_start=449
  _RESULT._serialized_end=577
  _RESULT_RESULTTYPE._serialized_start=520
  _RESULT_RESULTTYPE._serialized_end=577
  _LOG._serialized_start=579
  _LOG._serialized_end=705
  _LOG_SEVERITY._serialized_start=636
  _LOG_SEVERITY._serialized_end=705
  _HALT._serialized_start=707
  _HALT._serialized_end=713
  _HALTANDCATCHFIRE._serialized_start=715
  _HALTANDCATCHFIRE._serialized_end=733
  _MESSAGE._serialized_start=736
  _MESSAGE._serialized_end=1179
  _AGENTSPEC._serialized_start=1182
  _AGENTSPEC._serialized_end=1502
  _AGENTSPEC_ATTRIBUTESENTRY._serialized_start=1453
  _AGENTSPEC_ATTRIBUTESENTRY._serialized_end=1502
  _CREATEAGENT._serialized_start=1504
  _CREATEAGENT._serialized_end=1548
  _GETMESSAGESREQUEST._serialized_start=1550
  _GETMESSAGESREQUEST._serialized_end=1611
  _MESSAGESTACK._serialized_start=1613
  _MESSAGESTACK._serialized_end=1655
  _ACK._serialized_start=1657
  _ACK._serialized_end=1726
  _ACK_STATUS._serialized_start=1710
  _ACK_STATUS._serialized_end=1726
  _BLACKBOARDHANDLER._serialized_start=1790
  _BLACKBOARDHANDLER._serialized_end=1942
# @@protoc_insertion_point(module_scope)
